@@ -22,6 +22,9 @@
 #include <glom/libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Notebook_Data::Notebook_Data()
 {
   //Add Pages:
@@ -65,7 +68,9 @@ Notebook_Data::~Notebook_Data()
 bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value_for_details)
 {
   m_table_name = found_set.m_table_name;
-  const bool details_record_specified = !GlomConversions::value_is_empty(primary_key_value_for_details);
+  //std::cout << "Notebook_Data::init_db_details: table_name=" << m_table_name << std::endl;
+
+  const bool details_record_specified = !Conversions::value_is_empty(primary_key_value_for_details);
 
   bool result = false;
   //where_clause is only used as a result of a find.
@@ -78,8 +83,8 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
     const FoundSet old_found_set = m_Box_List.get_found_set();
     //std::cout << "  old_where_clause=" << old_where_clause << std::endl;
     //std::cout << "  where_clause=" << where_clause << std::endl;
-    const bool new_find_set = !(found_set == old_found_set);
-    result = m_Box_List.init_db_details(found_set);
+    //const bool new_find_set = !(found_set == old_found_set);
+    result = m_Box_List.init_db_details(found_set); //TODO: Select the last selected record.
     //m_Box_List.load_from_document();
 
     //Show the previously-shown record, if there is one, if this is not a new found-set (via a new where_clause)
@@ -89,7 +94,7 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
     {
       Gnome::Gda::Value primary_key_for_details;
 
-      if(!new_find_set && !details_record_specified)
+      if(!details_record_specified)
       {
         //std::cout << "debug: no new_found_set" << std::endl;
         primary_key_for_details = document->get_layout_record_viewed(m_table_name, m_Box_Details.get_layout_name());
@@ -103,12 +108,20 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
          //std::cout << "debug: new_found_set" << std::endl;
       }
 
-      if(GlomConversions::value_is_empty(primary_key_for_details))
+
+      //If the specified (or remembered) primary key value is not in the found set, 
+      //then ignore it:
+      if(!found_set.m_where_clause.empty() && !get_primary_key_is_in_foundset(found_set, primary_key_for_details))
+      {
+        primary_key_for_details = Gnome::Gda::Value(); //TODO: We set it to empty just so we can test if for empty.
+      }
+
+      if(Conversions::value_is_empty(primary_key_for_details))
       {
         //Make sure that the details view is not empty, if there are any records to show:
         primary_key_for_details = m_Box_List.get_primary_key_value_selected();
         //std::cout << "debug:  m_Box_List.get_primary_key_value_selected()=" << primary_key_for_details.to_string() << std::endl;
-        if(GlomConversions::value_is_empty(primary_key_for_details))
+        if(Conversions::value_is_empty(primary_key_for_details))
         {
           //std::cout << "debug: calling list.get_primary_key_value_first()" << std::endl;
           primary_key_for_details = m_Box_List.get_primary_key_value_first();
@@ -116,6 +129,7 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda:
         }
       }
 
+   
       m_Box_Details.init_db_details(found_set, primary_key_for_details);
     }
   }
@@ -190,8 +204,6 @@ void Notebook_Data::on_details_user_requested_related_details(const Glib::ustrin
 
 void Notebook_Data::set_current_view(dataview view)
 {
-  std::cout << "Notebook_Data::set_current_view" << std::endl;
-
   if(view == DATA_VIEW_List)
     set_current_page(m_iPage_List);
   else
@@ -295,3 +307,5 @@ void Notebook_Data::get_record_counts(gulong& total, gulong& found)
 {
   m_Box_List.get_record_counts(total, found);
 }
+
+} //namespace Glom
